==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CustomContourValueResolverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescription } from "./CustomContourValueResolverEventArgsDescription";
/**
 * @hidden
 */
var CustomContourValueResolverEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomContourValueResolverEventArgsDescriptionMetadata, _super);
    function CustomContourValueResolverEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomContourValueResolverEventArgsDescriptionMetadata.b = function (a) {
        if (CustomContourValueResolverEventArgsDescriptionMetadata.a == null) {
            CustomContourValueResolverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomContourValueResolverEventArgsDescriptionMetadata.c(CustomContourValueResolverEventArgsDescriptionMetadata.a);
        }
        if (a.g(CustomContourValueResolverEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CustomContourValueResolverEventArgsDescriptionMetadata.a);
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.c = function (a) {
        a.item("ContourValues", "Array:double");
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.d = function (a) {
        CustomContourValueResolverEventArgsDescriptionMetadata.b(a);
        a.u("CustomContourValueResolverEventArgs", function () { return new CustomContourValueResolverEventArgsDescription(); });
        a.t("CustomContourValueResolverEventArgs", CustomContourValueResolverEventArgsDescriptionMetadata.a);
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.$t = markType(CustomContourValueResolverEventArgsDescriptionMetadata, 'CustomContourValueResolverEventArgsDescriptionMetadata');
    CustomContourValueResolverEventArgsDescriptionMetadata.a = null;
    return CustomContourValueResolverEventArgsDescriptionMetadata;
}(Base));
export { CustomContourValueResolverEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CustomContourValueResolverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescription } from "./CustomContourValueResolverEventArgsDescription";
/**
 * @hidden
 */
var CustomContourValueResolverEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomContourValueResolverEventArgsDescriptionMetadata, _super);
    function CustomContourValueResolverEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomContourValueResolverEventArgsDescriptionMetadata.b = function (a) {
        if (CustomContourValueResolverEventArgsDescriptionMetadata.a == null) {
            CustomContourValueResolverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomContourValueResolverEventArgsDescriptionMetadata.c(CustomContourValueResolverEventArgsDescriptionMetadata.a);
        }
        if (a.j(CustomContourValueResolverEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CustomContourValueResolverEventArgsDescriptionMetadata.a);
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.c = function (a) {
        a.item("ContourValues", "Array:double");
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.d = function (a) {
        CustomContourValueResolverEventArgsDescriptionMetadata.b(a);
        a.aa("CustomContourValueResolverEventArgs", function () { return new CustomContourValueResolverEventArgsDescription(); });
        a.z("CustomContourValueResolverEventArgs", CustomContourValueResolverEventArgsDescriptionMetadata.a);
    };
    CustomContourValueResolverEventArgsDescriptionMetadata.$t = markType(CustomContourValueResolverEventArgsDescriptionMetadata, 'CustomContourValueResolverEventArgsDescriptionMetadata');
    CustomContourValueResolverEventArgsDescriptionMetadata.a = null;
    return CustomContourValueResolverEventArgsDescriptionMetadata;
}(Base));
export { CustomContourValueResolverEventArgsDescriptionMetadata };
